{% extends 'admin/change_list.html' %}
{% load i18n %}

{% block search %}{% endblock %}

{% block result_list %}
    <div
        id="tree"
        class="block-style"
        data-url="{{ tree_json_url }}"
        data-save_state="{{ app_label }}_{{ model_name }}"
        data-auto_open="{{ tree_auto_open }}"
        data-autoescape="{{ autoescape }}"
        data-label-edit="{% trans "edit" %}"
        data-label-move-failed="{% trans "move failed" %}"
        data-label-error="{% trans "Error while loading the data from the server" %}"
        {% if LANGUAGE_BIDI %}
            data-rtl
        {% endif %}
        data-use_context_menu="{{ use_context_menu }}"
    ></div>
{% endblock %}

{% block pagination %}{% endblock %}

{% block object-tools-items %}
    {{ block.super }}
    <li>
        <a href="{{ grid_url }}">{% trans "Grid view" %}</a>
    </li>
{% endblock %}
