#changelist {
    border: none;
}
#tree {
    padding: 1em 0 1em 0;
}
ul.jqtree-tree .jqtree-toggler {
    top: 10%;
}

#tree .edit {
    margin-left: 0.5em;
    vertical-align: middle;
}

.jqtree-tree .jqtree-loading > div .edit:after {
    content: url(spinner.gif);
    margin-left: 8px;
    position: absolute;
}

#tree.jqtree-loading:after {
    content: url(spinner.gif);
}

.jqtree-tree ul.jqtree_common {
    margin-top: 0;
}

.mptt-admin-error {
    color: red;
    margin-left: 8px;
}

.block-style ul.jqtree-tree {
    margin-left: 0;
}

.block-style ul.jqtree-tree ul.jqtree_common {
    margin-left: 2em;
}

.block-style ul.jqtree-tree .jqtree-element {
    margin-bottom: 8px;
    background-color: #eee;
    padding: 8px;
}

.block-style ul.jqtree-tree .jqtree-element .jqtree-title {
    margin-left: 0;
}

.block-style ul.jqtree-tree li.jqtree-selected > .jqtree-element {
    background: #79aec8;
    text-shadow: none;
}

.block-style ul.jqtree-tree li.jqtree-selected > .jqtree-element .jqtree-title {
    color: #fff;
}

.block-style ul.jqtree-tree li.jqtree-selected > .jqtree-element .edit {
    color: #c4dce8;
}
